@@ -1,8 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\Component;
 
 use org\bovigo\vfs\vfsStream;
+use PHPUnit\Framework\AssertionFailedError;
 use PHPUnit\Framework\TestCase;
 
 /**
@@ -15,7 +18,7 @@ class DrupalComponentTest extends TestCase {
   /**
    * Tests that classes in Component do not use any Core class.
    */
-  public function testNoCoreInComponent() {
+  public function testNoCoreInComponent(): void {
     $component_path = dirname(substr(__DIR__, 0, -strlen(__NAMESPACE__))) . '/lib/Drupal/Component';
     foreach ($this->findPhpClasses($component_path) as $class) {
       $this->assertNoCoreUsage($class);
@@ -25,7 +28,7 @@ class DrupalComponentTest extends TestCase {
   /**
    * Tests that classes in Component Tests do not use any Core class.
    */
-  public function testNoCoreInComponentTests() {
+  public function testNoCoreInComponentTests(): void {
     $component_path = dirname(substr(__DIR__, 0, -strlen(__NAMESPACE__))) . '/tests/Drupal/Tests/Component';
     foreach ($this->findPhpClasses($component_path) as $class) {
       $this->assertNoCoreUsage($class);
@@ -35,11 +38,12 @@ class DrupalComponentTest extends TestCase {
   /**
    * Tests LICENSE.txt is present and has the correct content.
    *
-   * @param $component_path
+   * @param string $component_path
    *   The path to the component.
-   * @dataProvider \Drupal\Tests\Component\DrupalComponentTest::getComponents
+   *
+   * @dataProvider getComponents
    */
-  public function testComponentLicence($component_path) {
+  public function testComponentLicense(string $component_path): void {
     $this->assertFileExists($component_path . DIRECTORY_SEPARATOR . 'LICENSE.txt');
     $this->assertSame('e84dac1d9fbb5a4a69e38654ce644cea769aa76b', hash_file('sha1', $component_path . DIRECTORY_SEPARATOR . 'LICENSE.txt'));
   }
@@ -49,7 +53,7 @@ class DrupalComponentTest extends TestCase {
    *
    * @return array
    */
-  public function getComponents() {
+  public static function getComponents(): array {
     $root_component_path = dirname(substr(__DIR__, 0, -strlen(__NAMESPACE__))) . '/lib/Drupal/Component';
     $component_paths = [];
     foreach (new \DirectoryIterator($root_component_path) as $file) {
@@ -88,26 +92,28 @@ class DrupalComponentTest extends TestCase {
    *
    * @param string $class_path
    *   The full path to the class that should be checked.
+   *
+   * @internal
    */
-  protected function assertNoCoreUsage($class_path) {
+  protected function assertNoCoreUsage(string $class_path): void {
     $contents = file_get_contents($class_path);
     preg_match_all('/^.*Drupal\\\Core.*$/m', $contents, $matches);
     $matches = array_filter($matches[0], function ($line) {
-      // Filter references to @see as they don't really matter.
-      return strpos($line, '@see') === FALSE;
+      // Filter references that don't really matter.
+      return preg_match('/@see|E_USER_DEPRECATED|expectDeprecation/', $line) === 0;
     });
     $this->assertEmpty($matches, "Checking for illegal reference to 'Drupal\\Core' namespace in $class_path");
   }
 
   /**
-   * Data provider for testAssertNoCoreUseage().
+   * Data provider for testAssertNoCoreUsage().
    *
    * @return array
-   *   Data for testAssertNoCoreUseage() in the form:
+   *   Data for testAssertNoCoreUsage() in the form:
    *   - TRUE if the test passes, FALSE otherwise.
    *   - File data as a string. This will be used as a virtual file.
    */
-  public function providerAssertNoCoreUseage() {
+  public static function providerAssertNoCoreUsage() {
     return [
       [
         TRUE,
@@ -132,9 +138,9 @@ class DrupalComponentTest extends TestCase {
 
   /**
    * @covers \Drupal\Tests\Component\DrupalComponentTest::assertNoCoreUsage
-   * @dataProvider providerAssertNoCoreUseage
+   * @dataProvider providerAssertNoCoreUsage
    */
-  public function testAssertNoCoreUseage($expected_pass, $file_data) {
+  public function testAssertNoCoreUsage($expected_pass, $file_data): void {
     // Set up a virtual file to read.
     $vfs_root = vfsStream::setup('root');
     vfsStream::newFile('Test.php')->at($vfs_root)->setContent($file_data);
@@ -144,7 +150,7 @@ class DrupalComponentTest extends TestCase {
       $pass = TRUE;
       $this->assertNoCoreUsage($file_uri);
     }
-    catch (\PHPUnit_Framework_AssertionFailedError $e) {
+    catch (AssertionFailedError $e) {
       $pass = FALSE;
     }
     $this->assertEquals($expected_pass, $pass, $expected_pass ?
